==> apache-sedona-1.4.1-src.tar.gz: apache-sedona-1.4.1-src/docs/community/contact.md <==
# Community

Every volunteer project obtains its strength from the people involved in it. We invite you to participate as much or as little as you choose.

You can participate in the community as follows:

* Use our project and provide a feedback.
* Provide us with the use-cases.
* Report bugs and submit patches.
* Contribute code and documentation.

## Twitter

[Apache Sedona@Twitter](https://twitter.com/ApacheSedona)

## Discord Server

Join [Apache Sedona community server](https://discord.gg/9A3k5dEBsY)!

## Mailing list

Get help using Sedona or contribute to the project on our mailing lists

[Sedona Mailing Lists](https://lists.apache.org/list.html?sedona.apache.org): [dev@sedona.apache.org](https://lists.apache.org/list.html?dev@sedona.apache.org): project development and general questions

* Please first subscribe and then post emails. To subscribe, please send an email (leave the subject and content blank) to dev-subscribe@sedona.apache.org

## Issue tracker

### Bug Reports

Found bug? Enter an issue in the [Sedona JIRA](https://issues.apache.org/jira/projects/SEDONA)

Before submitting an issue, please:

* Verify that the bug does in fact exist.
* Search the issue tracker to verify there is no existing issue reporting the bug you’ve found.
* Consider tracking down the bug yourself in the Sedona’s source and submitting a patch along with your bug report. This is a great time saver for the Sedona developers and helps ensure the bug will be fixed quickly.

### Feature Requests

Enhancement requests for new features are also welcome. The more concrete and rationale the request is, the greater the chance it will be incorporated into future releases.

Enter an issue in the [Sedona JIRA](https://issues.apache.org/jira/projects/SEDONA) or send an email to [dev@sedona.apache.org](https://lists.apache.org/list.html?dev@sedona.apache.org)

==> apache-sedona-1.5.0-src.tar.gz: apache-sedona-1.5.0-src/docs/community/contact.md <==
# Community

Every volunteer project obtains its strength from the people involved in it. We invite you to participate as much or as little as you choose.

You can participate in the community as follows:

* Use our project and provide a feedback.
* Provide us with the use-cases.
* Report bugs and submit patches.
* Contribute code and documentation.

## Twitter

[Apache Sedona@Twitter](https://twitter.com/ApacheSedona)

## Discord Server

[Join Apache Sedona community server](discord-invite-form.html)!

## Mailing list

Get help using Sedona or contribute to the project on our mailing lists

[Sedona Mailing Lists](https://lists.apache.org/list.html?sedona.apache.org): [dev@sedona.apache.org](https://lists.apache.org/list.html?dev@sedona.apache.org): project development and general questions

* Please first subscribe and then post emails. To subscribe, please send an email (leave the subject and content blank) to dev-subscribe@sedona.apache.org

## Issue tracker

### Bug Reports

Found bug? Enter an issue in the [Sedona JIRA](https://issues.apache.org/jira/projects/SEDONA)

Before submitting an issue, please:

* Verify that the bug does in fact exist.
* Search the issue tracker to verify there is no existing issue reporting the bug you’ve found.
* Consider tracking down the bug yourself in the Sedona’s source and submitting a patch along with your bug report. This is a great time saver for the Sedona developers and helps ensure the bug will be fixed quickly.

### Feature Requests

Enhancement requests for new features are also welcome. The more concrete and rationale the request is, the greater the chance it will be incorporated into future releases.

Enter an issue in the [Sedona JIRA](https://issues.apache.org/jira/projects/SEDONA) or send an email to [dev@sedona.apache.org](https://lists.apache.org/list.html?dev@sedona.apache.org)
